---------------------------------------------------------------------------------------------------------
--  REGISTER NEW FILLTYPES (ROCK, GOLD)
---------------------------------------------------------------------------------------------------------
-- Add two new fillTypes for the rocks to be spawned.
--
-- Author:		akuenzi (akuenzi@gmail.com)
-- Date:		6/28/2016
--
-- Sincere thanks to Xentro for his patient mentorship in creating this script.
--

-- New fillTypes to add.
newFillTypes = {
	{name = "rock", price = 0.0550, mass = 0.0025},
	{name = "gold", price = 75000, mass = 0.0193},
};

for i = 1, table.getn(newFillTypes) do
	local fillType = newFillTypes[i];
	local key = "FILLTYPE_"..string.upper(fillType.name);
	
	if Fillable[key] == nil then
		local hud = Utils.getFilename("Huds/" .. fillType.name .. "_hud.dds", g_currentModDirectory);
		local fillIndex = Fillable.registerFillType(fillType.name, g_i18n:getText(fillType.name), fillType.price, true, hud, hud, fillType.mass, math.rad(45));
		Fillable.fillTypeIndexToDesc[fillIndex].notInStorage = true;
	else
		print("The fillType " .. key .. " is already registered.  RockSpawn script did not register it again.")
	end;
end;


---------------------------------------------------------------------------------------------------------
--  REGISTER ROCKSPAWN SPECIALIZATION
---------------------------------------------------------------------------------------------------------
-- Add specialization to plows and cultivators, enabling them to 'dig up rocks.'
--
-- @author:    	Xentro (Marcus@Xentro.se)
-- @website:	www.Xentro.se
-- @history:	v1.53 - 2014-11-11 - Improvement
-- 				v1.52 - 2013-10-29 - 
--
-- @edit:  		akuenzi for RockSpawn mod (6/28/2016)
--

local l10nName = "LEVEL";

addSpecialization = {};
addSpecialization.isLoaded = true;
addSpecialization.g_currentModDirectory = g_currentModDirectory;

if SpecializationUtil.specializations["RockSpawn"] == nil then
	SpecializationUtil.registerSpecialization("RockSpawn", "RockSpawn", g_currentModDirectory .. "RockSpawn.lua")
	addSpecialization.isLoaded = false;
end;

addModEventListener(addSpecialization);

function addSpecialization:loadMap(name)	
    if not g_currentMission.RockSpawnModIsLoaded then
		if not addSpecialization.isLoaded then
			addSpecialization:add();
			addSpecialization.isLoaded = true;
		end;
		
		g_currentMission.RockSpawnModIsLoaded = true;
	else
		print("RockSpawn - Error: The RockSpawn mod has been loaded already! Please remove one of the copies.");
	end;
end;

function addSpecialization:deleteMap()
	g_currentMission.RockSpawnModIsLoaded = nil;
end;

function addSpecialization:mouseEvent(posX, posY, isDown, isUp, button)
end;

function addSpecialization:keyEvent(unicode, sym, modifier, isDown)
end;

function addSpecialization:update(dt)
end;

function addSpecialization:draw()
end;

function addSpecialization:add()
	
	RockSpawnVehicles = {"cultivator", "plough"} -- the separate vehicles allowed to run the RockSpawn script.
	
	for i = 1, table.getn(RockSpawnVehicles) do
	
		local searchWords = {};
		local searchSpecializations = {{"RockSpawn", false},{RockSpawnVehicles[i], true}}; -- only globally accessible scripts. (steerable, fillable etc.) 
		
		for k, vehicle in pairs(VehicleTypeUtil.vehicleTypes) do
			local locationAllowed, specialization;
		
			
			for _, s in ipairs(searchSpecializations) do s[3] = false; end;

			for _, vs in ipairs(vehicle.specializations) do
				for _, s in ipairs(searchSpecializations) do
					if vs == SpecializationUtil.getSpecialization(s[1]) then
						if s[2] then
							locationAllowed = "allowed";
							s[3] = true;
						else
							locationAllowed = "has";
							specialization = s[1];
							break;
						end;
					end;
				end;
				
				if locationAllowed ~= nil and locationAllowed ~= "allowed" then
					break;
				end;
			end;
			
			if locationAllowed == nil then
				locationAllowed = "allowed";
			end;
			
			for _, s in ipairs(searchSpecializations) do
				if s[2] then
					if s[3] ~= true then
						locationAllowed = "missing";
						specialization = s[1];
						break;
					end;
				end;
			end;
			
			if locationAllowed == "allowed" then
				local addSpec;
				local modName = Utils.splitString(".", k);
				local spec = {};
				
				for name in pairs(SpecializationUtil.specializations) do
					if string.find(name, modName[1]) ~= nil then
						local parts = Utils.splitString(".", name);
						
						if table.getn(parts) > 1 then
							table.insert(spec, parts);
						end;
					end;
				end;
				
				for _, s in ipairs(spec) do
					for _, search in ipairs(searchWords) do
						if string.find(string.lower(s[2]), string.lower(search)) ~= nil then
							addSpec = s[2];
							break;
						end;
					end;
					
					if addSpec ~= nil then
						break;
					end;
				end;
				
				if addSpec == nil then
					table.insert(vehicle.specializations, SpecializationUtil.getSpecialization("RockSpawn"));
					--	print("RockSpawn: Inserted on " .. k);
				else
					print("RockSpawn: Failed inserting on " .. k .. " as it has the specialization (" .. addSpec .. ")");
				end;
			elseif locationAllowed == "has" then
				print("RockSpawn: Failed inserting on " .. k .. " as it has the specialization (" .. specialization .. ")");
			else
				-- print("RockSpawn: Failed inserting on " .. k .. " as its missing specialization " .. specialization);
			end;
		end;
	end;
	
	--make l10n global
	g_i18n.globalI18N.texts["RockStatus"] = g_i18n:getText("RockStatus");
	g_i18n.globalI18N.texts["WE_ARE_ACTIVE"] = g_i18n:getText("WE_ARE_ACTIVE");
	
	local i = 0;
	while true do
		local txt = string.format(l10nName .. "_%d", i);
		if not g_i18n:hasText(txt) then
			break;
		end;
		g_i18n.globalI18N.texts[txt] = g_i18n:getText(txt);
		
		i = i + 1;
	end;
end;
